@@ -2,18 +2,19 @@ import test from 'ava';
 import {getFixture, assertDirectory} from './helpers/util';
 import makeDir from '..';
 
+const mask = 0;
 test.before(() => {
-	process.umask(0);
+	process.umask(mask);
 });
 
 test('async', async t => {
 	const dir = getFixture();
 	await makeDir(dir);
-	assertDirectory(t, dir, 0o777 & (~process.umask()));
+	assertDirectory(t, dir, 0o777 & (~mask));
 });
 
 test('sync', t => {
 	const dir = getFixture();
 	makeDir.sync(dir);
-	assertDirectory(t, dir, 0o777 & (~process.umask()));
+	assertDirectory(t, dir, 0o777 & (~mask));
 });
